@@ -844,6 +844,12 @@ trace_to_soup_message (const gchar *trace, GUri *base_uri)
 	} else if (strncmp (trace, "PUT", strlen ("PUT")) == 0) {
 		method = SOUP_METHOD_PUT;
 		trace += strlen ("PUT");
+	} else if (strncmp (trace, "PATCH", strlen ("PATCH")) == 0) {
+		method = "PATCH";
+		trace += strlen ("PATCH");
+	} else if (strncmp (trace, "CONNECT", strlen ("CONNECT")) == 0) {
+		method = "CONNECT";
+		trace += strlen ("CONNECT");
 	} else {
 		g_warning ("Unknown method ‘%s’.", trace);
 		goto error;
